complete -c sqopv -n "__fish_use_subcommand" -l debug -d 'Emit verbose output for debugging'
complete -c sqopv -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c sqopv -n "__fish_use_subcommand" -f -a "version" -d 'Prints version information'
complete -c sqopv -n "__fish_use_subcommand" -f -a "verify" -d 'Verifies Detached Signatures'
complete -c sqopv -n "__fish_use_subcommand" -f -a "inline-verify" -d 'Verifies Inline-Signed Messages'
complete -c sqopv -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c sqopv -n "__fish_seen_subcommand_from version" -l backend -d 'Returns name and version of the primary underlying OpenPGP toolkit'
complete -c sqopv -n "__fish_seen_subcommand_from version" -l extended -d 'Returns multiple lines of name and version information'
complete -c sqopv -n "__fish_seen_subcommand_from version" -l sop-spec -d 'Returns the latest version of the SOP spec that is implemented'
complete -c sqopv -n "__fish_seen_subcommand_from version" -l sopv -d 'Returns "1.0\\n" if the sopv subset is implemented'
complete -c sqopv -n "__fish_seen_subcommand_from version" -l debug -d 'Emit verbose output for debugging'
complete -c sqopv -n "__fish_seen_subcommand_from version" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c sqopv -n "__fish_seen_subcommand_from verify" -l not-before -d 'Consider signatures before this date invalid' -r
complete -c sqopv -n "__fish_seen_subcommand_from verify" -l not-after -d 'Consider signatures after this date invalid' -r
complete -c sqopv -n "__fish_seen_subcommand_from verify" -l debug -d 'Emit verbose output for debugging'
complete -c sqopv -n "__fish_seen_subcommand_from verify" -s h -l help -d 'Print help'
complete -c sqopv -n "__fish_seen_subcommand_from inline-verify" -l not-before -d 'Consider signatures before this date invalid' -r
complete -c sqopv -n "__fish_seen_subcommand_from inline-verify" -l not-after -d 'Consider signatures after this date invalid' -r
complete -c sqopv -n "__fish_seen_subcommand_from inline-verify" -l verifications-out -d 'Write verification result here' -r
complete -c sqopv -n "__fish_seen_subcommand_from inline-verify" -l debug -d 'Emit verbose output for debugging'
complete -c sqopv -n "__fish_seen_subcommand_from inline-verify" -s h -l help -d 'Print help'
complete -c sqopv -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from inline-verify; and not __fish_seen_subcommand_from help" -f -a "version" -d 'Prints version information'
complete -c sqopv -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from inline-verify; and not __fish_seen_subcommand_from help" -f -a "verify" -d 'Verifies Detached Signatures'
complete -c sqopv -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from inline-verify; and not __fish_seen_subcommand_from help" -f -a "inline-verify" -d 'Verifies Inline-Signed Messages'
complete -c sqopv -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from version; and not __fish_seen_subcommand_from verify; and not __fish_seen_subcommand_from inline-verify; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
